==> inkribbon-6.x-5.3.tar.gz: inkribbon/templates/maintenance-page.tpl.php <==
<?php
// $Id: maintenance-page.tpl.php,v 1.1.2.8 2010/04/20 07:32:40 mverbaar Exp $
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
  "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="<?php print $language->language ?>" lang="<?php print $language->language ?>" dir="<?php print $language->dir ?>">
<head>
  <?php print $head; ?>
  <title><?php print $head_title; ?></title>
  <?php print $styles; ?>
  <?php print $scripts; ?>
</head>
<body class="<?php print $body_classes; ?>">
  
  <div id="page-wrapper"><div id="page">
    
    <div id="header"><div class="section">
      
      <?php if ($logo): ?>
        <div id="logo"><?php print $logo; ?></div>
      <?php endif; ?>

      <?php if ($site_name): ?>
        <?php
        // Use h1 when the content title is empty.
        $site_name_wrapper = ($title) ? 'div' : 'h1';
        ?>
        <<?php print $site_name_wrapper; ?> id="site-name">
          <?php print $site_name; ?>
        </<?php print $site_name_wrapper; ?>>
      <?php endif; ?>

      <?php if ($site_slogan): ?>
        <div id="site-slogan"><?php print $site_slogan; ?></div>
      <?php endif; ?>

      <?php if ($header): ?>
        <div class="region region-header"><?php print $header; ?></div>
      <?php endif; ?>
      
    </div></div> <!-- /.section, /#header -->
    
    <?php print $breadcrumb; ?>
    <?php print $messages; ?>

    <div id="main-wrapper"><div id="main" class="clear-block">

      <div id="content" class="column"><div class="section">
        <?php if ($highlight): ?>
          <div id="highlight"><?php print $highlight; ?></div>
        <?php endif; ?>
        
        <?php if ($title): ?>
          <h1 id="page-title"><?php print $title; ?></h1>
        <?php endif; ?>
        
        <?php print $tabs; ?>
        <?php print $help; ?>
        <?php print $content; ?>
      </div></div><!-- /.section, /#content -->
      
      <?php if ($left): ?>
        <div id="sidebar-left" class="column sidebar"><div class="section">
          <?php print $left; ?>
        </div></div> <!-- /.section, /#sidebar-left -->
      <?php endif; ?>

      <?php if ($right): ?>
        <div id="sidebar-right" class="column sidebar"><div class="section">
          <?php print $right; ?>
        </div></div> <!-- /.section, /#sidebar-right -->
      <?php endif; ?>

    </div></div> <!-- /#main, /#main-wrapper -->

    <div id="footer"><div class="section">
      <?php print $footer; ?>
    </div></div> <!-- /.section, /#footer -->

    <?php print $closure; ?>

  </div></div> <!-- /#page, /#page-wrapper -->

</body>
</html>

==> inkribbon-6.x-5.6.tar.gz: inkribbon/templates/maintenance-page.tpl.php <==
<?php
// $Id: maintenance-page.tpl.php,v 1.1.2.10 2010/04/28 12:42:48 mverbaar Exp $
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
  "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="<?php print $language->language ?>" lang="<?php print $language->language ?>" dir="<?php print $language->dir ?>">
<head>
  <?php print $head; ?>
  <title><?php print $head_title; ?></title>
  <?php print $styles; ?>
  <?php print $scripts; ?>
</head>
<body class="<?php print $body_classes; ?>">
  
  <div id="page-wrapper"><div id="page">
    
    <div id="header"><div class="section clear-block">
      
      <?php if ($logo): ?>
        <div id="logo"><?php print $logo; ?></div>
      <?php endif; ?>

      <?php if ($site_name): ?>
        <?php
          // Use h1 when the content title is empty.
          $site_name_wrapper = ($title) ? 'div' : 'h1';
        ?>
        <<?php print $site_name_wrapper; ?> id="site-name">
          <?php print $site_name; ?>
        </<?php print $site_name_wrapper; ?>>
      <?php endif; ?>

      <?php if ($site_slogan): ?>
        <div id="site-slogan"><?php print $site_slogan; ?></div>
      <?php endif; ?>

      <?php if ($header): ?>
        <div class="region region-header"><?php print $header; ?></div>
      <?php endif; ?>
      
    </div></div> <!-- /.section, /#header -->
    
    <?php print $breadcrumb; ?>
    <?php print $messages; ?>

    <div id="main-wrapper"><div id="main" class="clear-block">

      <div id="content" class="column"><div class="section">
        <?php if ($highlight): ?>
          <div id="highlight"><?php print $highlight; ?></div>
        <?php endif; ?>
        
        <?php if ($title): ?>
          <h1 id="page-title"><?php print $title; ?></h1>
        <?php endif; ?>
        
        <?php print $tabs; ?>
        <?php print $help; ?>
        <?php print $content; ?>
      </div></div><!-- /.section, /#content -->
      
      <?php if ($left): ?>
        <div id="sidebar-left" class="column sidebar"><div class="section">
          <?php print $left; ?>
        </div></div> <!-- /.section, /#sidebar-left -->
      <?php endif; ?>

      <?php if ($right): ?>
        <div id="sidebar-right" class="column sidebar"><div class="section">
          <?php print $right; ?>
        </div></div> <!-- /.section, /#sidebar-right -->
      <?php endif; ?>

    </div></div> <!-- /#main, /#main-wrapper -->

    <div id="footer"><div class="section clear-block">
      <?php print $footer; ?>
    </div></div> <!-- /.section, /#footer -->

    <?php print $closure; ?>

  </div></div> <!-- /#page, /#page-wrapper -->

</body>
</html>
